@@ -185,7 +185,10 @@ def load_dataset(path_metadata_file: str,
     :return: (*Dataset*) A dataset object.
     """
 
-    metadata = numpy.array(pandas.read_excel(path_metadata_file))
+    metadata_file = pandas.read_excel(path_metadata_file)
+    metadata = numpy.array(metadata_file)
+    names_feats = [metadata_file.columns.values[idx_mat_id]]
+    name_target = None if idx_target is None else metadata_file.columns.values[idx_target]
     rbf_means = torch.tensor(numpy.linspace(start=0.7, stop=atomic_cutoff, num=n_kerl_centers), dtype=torch.float)
     iter_range = range(0, metadata.shape[0])
     list_data = list()
@@ -206,4 +209,9 @@ def load_dataset(path_metadata_file: str,
         else:
             list_data.append(Data(x=crystal_graph, y=metadata[i, idx_target], idx=i, dtype=DTYPE_CSTRUCT))
 
-    return Dataset(list_data, idx_mat_id=idx_mat_id, idx_target=idx_target, atomic_cutoff=atomic_cutoff)
+    return Dataset(list_data,
+                   idx_mat_id=idx_mat_id,
+                   idx_target=idx_target,
+                   names_feats=names_feats,
+                   name_target=name_target,
+                   atomic_cutoff=atomic_cutoff)
