@@ -60,7 +60,10 @@ def load_dataset(path_data_file: str,
     :return: (*Dataset*) A dataset object.
     """
 
-    data = numpy.array(pandas.read_excel(path_data_file))
+    data_file = pandas.read_excel(path_data_file)
+    data = numpy.array(data_file)
+    names_feats = [data_file.columns.values[idx_form]]
+    name_target = None if idx_target is None else data_file.columns.values[idx_target]
     iter_range = range(0, data.shape[0])
     list_data = list()
 
@@ -75,7 +78,12 @@ def load_dataset(path_data_file: str,
         else:
             list_data.append(Data(x=form_vec, y=data[i, idx_target], idx=i, dtype=DTYPE_FORM))
 
-    return Dataset(list_data, idx_form=idx_form, idx_target=idx_target, form_rep_type=form_rep_type)
+    return Dataset(list_data,
+                   idx_form=idx_form,
+                   idx_target=idx_target,
+                   names_feats=names_feats,
+                   name_target=name_target,
+                   form_rep_type=form_rep_type)
 
 
 def __get_compact_form_vec(form: str,
