@@ -35,7 +35,11 @@ def load_dataset(path_metadata_file: str,
     """
 
     ext_img = '.' + ext_img
-    metadata = numpy.array(pandas.read_excel(path_metadata_file))
+    metadata_file = pandas.read_excel(path_metadata_file)
+    metadata = numpy.array(metadata_file)
+    names_feats = [metadata_file.columns.values[idx_img_id]]
+    name_target = None if idx_target is None else metadata_file.columns.values[idx_target]
+
     iter_range = range(0, metadata.shape[0])
     list_data = list()
 
@@ -54,4 +58,9 @@ def load_dataset(path_metadata_file: str,
         else:
             list_data.append(Data(x=img, y=metadata[i, idx_target], idx=i, dtype=DTYPE_IMG))
 
-    return Dataset(list_data, idx_img_id=idx_img_id, idx_target=idx_target, ext_img=ext_img)
+    return Dataset(list_data,
+                   idx_img_id=idx_img_id,
+                   idx_target=idx_target,
+                   names_feats=names_feats,
+                   name_target=name_target,
+                   ext_img=ext_img)
