@@ -1,6 +1,4 @@
 from itertools import product
-from copy import deepcopy
-from ailca.ml.base import SKLearnModel
 from ailca.ml.util import *
 from ailca.data.base import Dataset
 from ailca.data.util import get_data_loader
